==> foundation-2.6.1.tgz: package/Crown/Crown.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Crown = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", {
    fillRule: "evenodd",
    clipRule: "evenodd"
  }, /*#__PURE__*/React.createElement("path", {
    d: "M84.01 79.998a3.044 3.044 0 00-3.042-3.043H19.033a3.044 3.044 0 00-3.042 3.043v3.871a3.041 3.041 0 003.042 3.042h61.935a3.04 3.04 0 003.042-3.042v-3.871zM24.619 38.433l-.017-.017-.002.002a3.24 3.24 0 00-2.118-.798 3.264 3.264 0 00-3.26 3.193h-.08v29.238h.103c.155 1.659 1.536 2.965 3.237 2.965.012 0 .024-.003.036-.004v.004h54.963v-.076c.013 0 .024.004.037.004 1.675 0 3.041-1.268 3.229-2.893h.037V41.42a3.267 3.267 0 00-3.194-3.945c-.776 0-1.479.282-2.04.733l-.009-.009-.091.091a3.169 3.169 0 00-.312.312l-6.881 6.881-15.852-15.852-.031.031a3.248 3.248 0 00-2.373-1.033 3.25 3.25 0 00-2.377 1.037l-.035-.035-15.887 15.885-6.766-6.767a3.502 3.502 0 00-.317-.316zm48.354 8.394v.095h-.095l.095-.095z"
  }), /*#__PURE__*/React.createElement("circle", {
    cx: 22.348,
    cy: 27.13,
    r: 6.042
  }), /*#__PURE__*/React.createElement("circle", {
    cx: 77.348,
    cy: 27.13,
    r: 6.042
  }), /*#__PURE__*/React.createElement("circle", {
    cx: 50.348,
    cy: 19.13,
    r: 6.042
  })));
});
Crown.displayName = 'Crown';
export const CrownDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/Crown/Crown.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Crown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", {
    fillRule: "evenodd",
    clipRule: "evenodd"
  }, /*#__PURE__*/React.createElement("path", {
    d: "M84.01 79.998a3.044 3.044 0 00-3.042-3.043H19.033a3.044 3.044 0 00-3.042 3.043v3.871a3.041 3.041 0 003.042 3.042h61.935a3.04 3.04 0 003.042-3.042v-3.871zM24.619 38.433l-.017-.017-.002.002a3.24 3.24 0 00-2.118-.798 3.264 3.264 0 00-3.26 3.193h-.08v29.238h.103c.155 1.659 1.536 2.965 3.237 2.965.012 0 .024-.003.036-.004v.004h54.963v-.076c.013 0 .024.004.037.004 1.675 0 3.041-1.268 3.229-2.893h.037V41.42a3.267 3.267 0 00-3.194-3.945c-.776 0-1.479.282-2.04.733l-.009-.009-.091.091a3.169 3.169 0 00-.312.312l-6.881 6.881-15.852-15.852-.031.031a3.248 3.248 0 00-2.373-1.033 3.25 3.25 0 00-2.377 1.037l-.035-.035-15.887 15.885-6.766-6.767a3.502 3.502 0 00-.317-.316zm48.354 8.394v.095h-.095l.095-.095z"
  }), /*#__PURE__*/React.createElement("circle", {
    cx: 22.348,
    cy: 27.13,
    r: 6.042
  }), /*#__PURE__*/React.createElement("circle", {
    cx: 77.348,
    cy: 27.13,
    r: 6.042
  }), /*#__PURE__*/React.createElement("circle", {
    cx: 50.348,
    cy: 19.13,
    r: 6.042
  })));
});
Crown.displayName = 'Crown';
export var CrownDimensions = {
  height: 100,
  width: 100
};
